diff mbox

[PULL,02/65] ram: Rename flush_page_queue() to migration_page_queue_free()

Message ID 20170421115646.15544-3-quintela@redhat.com
State New
Headers show

Commit Message

Juan Quintela April 21, 2017, 11:55 a.m. UTC
It reflects better what it does.

Signed-off-by: Juan Quintela <quintela@redhat.com>
Reviewed-by: Dr. David Alan Gilbert <dgilbert@redhat.com>
Reviewed-by: Peter Xu <peterx@redhat.com>
---
 include/migration/migration.h | 2 +-
 migration/migration.c         | 2 +-
 migration/ram.c               | 5 +++--
 3 files changed, 5 insertions(+), 4 deletions(-)
diff mbox

Patch

diff --git a/include/migration/migration.h b/include/migration/migration.h
index 5720c88..24487be 100644
--- a/include/migration/migration.h
+++ b/include/migration/migration.h
@@ -377,7 +377,7 @@  void savevm_skip_configuration(void);
 int global_state_store(void);
 void global_state_store_running(void);
 
-void flush_page_queue(MigrationState *ms);
+void migration_page_queue_free(MigrationState *ms);
 int ram_save_queue_pages(MigrationState *ms, const char *rbname,
                          ram_addr_t start, ram_addr_t len);
 uint64_t ram_pagesize_summary(void);
diff --git a/migration/migration.c b/migration/migration.c
index ad4036f..4bee05d 100644
--- a/migration/migration.c
+++ b/migration/migration.c
@@ -955,7 +955,7 @@  static void migrate_fd_cleanup(void *opaque)
     qemu_bh_delete(s->cleanup_bh);
     s->cleanup_bh = NULL;
 
-    flush_page_queue(s);
+    migration_page_queue_free(s);
 
     if (s->to_dst_file) {
         trace_migrate_fd_cleanup();
diff --git a/migration/ram.c b/migration/ram.c
index 652abe4..356f8ce 100644
--- a/migration/ram.c
+++ b/migration/ram.c
@@ -1186,14 +1186,15 @@  static bool get_queued_page(MigrationState *ms, PageSearchStatus *pss,
 }
 
 /**
  * flush_page_queue: flush any remaining pages in the ram request queue
  *
  * It should be empty at the end anyway, but in error cases there may
  * be some left.  in case that there is any page left, we drop it.
  *
  * @ms: current migration state
  */
-void flush_page_queue(MigrationState *ms)
+void migration_page_queue_free(MigrationState *ms)
 {
     struct MigrationSrcPageRequest *mspr, *next_mspr;
     /* This queue generally should be empty - but in the case of a failed
@@ -1186,14 +1186,15 @@  static bool get_queued_page(MigrationState *ms, PageSearchStatus *pss,
 
 /**
- * flush_page_queue: flush any remaining pages in the ram request queue
+ * migration_page_queue_free: drop any remaining pages in the ram
+ * request queue
  *
  * It should be empty at the end anyway, but in error cases there may